On Thu, Aug 14, 2014 at 12:25:14PM +0100, Filipe Manana wrote:
> The map_start and map_len fields aren't used anywhere, so just remove
> them. On a x86_64 system, this reduced sizeof(struct extent_buffer)
> from 296 bytes to 280 bytes, and therefore 14 extent_buffer structs can
> now fit into a page instead of 13.
> 
> Signed-off-by: Filipe Manana <[email protected]>
Reviewed-by: David Sterba <[email protected]>

Nice catch.
--
To unsubscribe from this list: send the line "unsubscribe linux-btrfs" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to